package ch.hslu.appe.order.model;

import java.util.Date;
import java.util.List;

import ch.hslu.appe.usermanagement.model.Address;
import ch.hslu.appe.usermanagement.model.User;

/**
 * The order contains all required information about one order.
 * @author Felix Rohrer <felix.rohrer@stud.hslu.ch>
 */
public final class Order {

    private int id;
    private int number;
    private OrderState orderState;
    private Date orderDate;
    private DeliverState deliverState;
    private Date deliverDate;
    private Address deliverAddress;
    private BillState payState;
    private float deliverCost;
    private User customer;
    private User sales;
    private List<OrderPosition> orderPositions;
    private List<Bill> bills;

    /**
     * Empty Default Constructor.
     */
    public Order() {
        // Empty Constructor
    }

    /**
     * gets all bills within this order.
     * @return the bill list
     */
    public List<Bill> getBills() {
        return bills;
    }

    /**
     * gets the customer user.
     * @return the customer user
     */
    public User getCustomer() {
        return customer;
    }

    /**
     * gets the deliver address.
     * @return the deliveraddress
     */
    public Address getDeliverAddress() {
        return deliverAddress;
    }

    /**
     * gets the deliver costs.
     * @return the delivercost
     */
    public float getDeliverCost() {
        return deliverCost;
    }

    /**
     * gets the deliver date.
     * @return the deliverdate
     */
    public Date getDeliverDate() {
        return deliverDate;
    }

    /**
     * gets the deliver state.
     * @return the deliverstate
     */
    public DeliverState getDeliverState() {
        return deliverState;
    }

    /**
     * gets the unique order id, generated by the database.
     * @return the id
     */
    public int getId() {
        return id;
    }

    /**
     * gets the order number.
     * @return the number
     */
    public int getNumber() {
        return number;
    }

    /**
     * gets the order date.
     * @return the orderdate
     */
    public Date getOrderDate() {
        return orderDate;
    }

    /**
     * gets all positions within this order.
     * @return the orderposition list
     */
    public List<OrderPosition> getOrderPositions() {
        return orderPositions;
    }

    /**
     * gets the order state.
     * @return the orderstate
     */
    public OrderState getOrderState() {
        return orderState;
    }

    /**
     * gets the pay state.
     * @return the paystate
     */
    public BillState getPayState() {
        return payState;
    }

    /**
     * gets the sales user.
     * @return the sales user
     */
    public User getSales() {
        return sales;
    }

    /**
     * sets the whole list of bills within this order.
     * @param newBills the whole list of bills within this order to set
     */
    public void setBills(final List<Bill> newBills) {
        this.bills = newBills;
    }

    /**
     * sets the customer user.
     * @param customer the customer user to set
     */
    public void setCustomer(final User customer) {
        this.customer = customer;
    }

    /**
     * sets the deliver address.
     * @param deliverAddress to be set
     */
    public void setDeliverAddress(final Address deliverAddress) {
        this.deliverAddress = deliverAddress;
    }

    /**
     * sets the deliver costs.
     * @param deliverCost the delivercost to set
     */
    public void setDeliverCost(final float deliverCost) {
        this.deliverCost = deliverCost;
    }

    /**
     * sets the deliver date.
     * @param deliverDate the deliverdate to set
     */
    public void setDeliverDate(final Date deliverDate) {
        this.deliverDate = deliverDate;
    }

    /**
     * sets the deliver state.
     * @param deliverState the deliverstate to set
     */
    public void setDeliverState(final DeliverState deliverState) {
        this.deliverState = deliverState;
    }

    /**
     * Sets the id of the Order.
     * @param id new orderId
     */
    public void setId(final int id) {
        this.id = id;
    }

    /**
     * sets the order number.
     * @param number the order number to set
     */
    public void setNumber(final int number) {
        this.number = number;
    }

    /**
     * sets the order date.
     * @param orderDate to set
     */
    public void setOrderDate(final Date orderDate) {
        this.orderDate = orderDate;
    }

    /**
     * sets the whole list of products within this order.
     * @param newOrderPositions the whole list of products within this order to set
     */
    public void setOrderPositions(final List<OrderPosition> newOrderPositions) {
        this.orderPositions = newOrderPositions;
    }

    /**
     * sets the order state.
     * @param orderState the orderstate to set
     */
    public void setOrderState(final OrderState orderState) {
        this.orderState = orderState;
    }

    /**
     * sets the pay state.
     * @param payState the paystate to set
     */
    public void setPayState(final BillState payState) {
        this.payState = payState;
    }

    /**
     * sets the sales user.
     * @param salesUser the sales user to set
     */
    public void setSales(final User salesUser) {
        this.sales = salesUser;
    }

}
