package ch.hslu.appe.usermanagement.filter;

import java.util.HashMap;
import java.util.Map;

import ch.hslu.appe.filter.Filter;
import ch.hslu.appe.usermanagement.model.Place;

/**
 * Place Filter.
 */
public final class PlaceFilter implements Filter<Place> {

    private int id;
    private int zipCode;
    private String name;
    private String canton;

    /**
     * Return the Canton.
     * @return canton
     */
    public String getCanton() {
        return canton;
    }

    @Override
    public Map<String, Object> getFilter() {
        final Map<String, Object> filter = new HashMap<String, Object>();

        // Add filter criteria
        if (id > 0) {
            filter.put("id", id);
        }

        if (canton != null && !canton.isEmpty()) {
            filter.put("canton", canton);
        }

        if (zipCode > 0) {
            filter.put("zipCode", zipCode);
        }

        if (name != null && !name.isEmpty()) {
            filter.put("name", name);
        }

        return filter;
    }

    /**
     * Return the ID.
     * @return id
     */
    public int getId() {
        return id;
    }

    /**
     * Return the Name.
     * @return name
     */
    public String getName() {
        return name;
    }

    /**
     * Return the ZipCode.
     * @return zip code
     */
    public int getZipCode() {
        return zipCode;
    }

    @Override
    public boolean match(final Place other) {

        // Check the id
        if (id > 0 && other.getId() != id) {
            return false;
        }

        // Check the canton
        if (canton != null && !canton.isEmpty() && !other.getCanton().matches(canton.replace("%", ".*"))) {
            return false;
        }

        // Check the zip code
        if (zipCode > 0 && other.getZipCode() != zipCode) {
            return false;
        }

        // Check the name
        if (name != null && !name.isEmpty() && !other.getName().matches(name.replace("%", ".*"))) {
            return false;
        }

        return true;
    }

    /**
     * Sets the Canton.
     * @param canton to be set
     */
    public void setCanton(final String canton) {
        this.canton = canton;
    }

    /**
     * Sets the ID.
     * @param id to be set
     */
    public void setId(final int id) {
        this.id = id;
    }

    /**
     * Sets the Name.
     * @param name to be set
     */
    public void setName(final String name) {
        this.name = name;
    }

    /**
     * Sets the ZipCode.
     * @param zipCode to be set
     */
    public void setZipCode(final int zipCode) {
        this.zipCode = zipCode;
    }
}
