package ch.hslu.appe.usermanagement.persistency;

import java.util.List;

import ch.hslu.appe.usermanagement.exception.MultipleHomeAddressesException;
import ch.hslu.appe.usermanagement.model.Address;

/**
 * Address Persistency Interface.
 */
public interface AddressPersistency {

    /**
     * Adds an address to a user.
     * @param userId The user id
     * @param address The address
     * @return Returns true on success, otherwise false
     * @throws MultipleHomeAddressesException user has multiple home addresses
     */
    boolean addAddress(int userId, Address address) throws MultipleHomeAddressesException;

    /**
     * Checks whether an address exists.
     * @param address The address
     * @return Returns true if the address exists, otherwise false
     */
    boolean addressExists(Address address);

    /**
     * Deletes an address.
     * @param addressId The address id
     * @return Returns true on success, otherwise false
     */
    boolean deleteAddress(int addressId);

    /**
     * Returns a specific address.
     * @param addressId The address id
     * @return Returns an address
     */
    Address getAddress(int addressId);

    /**
     * Gets all addresses of a specific user.
     * @param userId The user id
     * @return Returns a list of addresses which belongs to the user
     */
    List<Address> getUserAddresses(int userId);

    /**
     * Updates an address.
     * @param address The address
     * @return true if success otherwise false
     */
    boolean updateAddress(final Address address);
}
